@@ -29,7 +29,7 @@ import six
 from six.moves import cPickle as pickle
 from collections import defaultdict
 
-from .base import base_store
+from .base import base_store, base_lock
 
 def _gen_key(key, name):
     if type(name) != six.text_type:
@@ -104,7 +104,7 @@ class dict_store(base_store):
             del self.store[_resultname(name)]
 
 
-    def cleanup(self, active):
+    def cleanup(self, active, keeplocks=False):
         '''
         cleanup()
 
@@ -116,9 +116,20 @@ class dict_store(base_store):
                 existing.remove(_resultname(act))
             except KeyError:
                 pass
+
+        if keeplocks:
+            for lock in self.listlocks():
+                try:
+                    existing.remove(_lockname(lock))
+                except ValueError:
+                    pass
+
+        cleaned = len(existing)
         for superflous in existing:
             del self.store[superflous]
 
+        return cleaned
+
     def remove_locks(self):
         '''
         removed = store.remove_locks()
@@ -167,13 +178,13 @@ class dict_store(base_store):
 
     def close(self):
         if self.backend is not None:
-            pickle.dump(self.store, file(self.backend, 'w'))
+            pickle.dump(self.store, open(self.backend, 'w'))
             self.backend = None
     __del__ = close
 
 
 _NOT_LOCKED, _LOCKED = 0,1
-class dict_lock(object):
+class dict_lock(base_lock):
     '''
     dict_lock
 
