@@ -83,7 +83,12 @@ class compress_stream(object):
         self.C = zlib.compressobj()
 
     def write(self, s):
-        self.stream.write(self.C.compress(s))
+        MAX_BLOCK = 2000000000
+        if len(s) > MAX_BLOCK:
+            self.stream.write(self.C.compress(s[:MAX_BLOCK]))
+            self.write(s[MAX_BLOCK:])
+        else:
+            self.stream.write(self.C.compress(s))
 
     def flush(self):
         self.stream.write(self.C.flush())
@@ -151,7 +156,6 @@ class decompress_stream(object):
                 line += block[:ln]
                 self.seek(ln-len(block), 1)
                 return line
-        return line
 
 def decode(s):
     '''
